<?php
include 'auth_check.php'; // Include verificarea autentificării
include 'config.php'; // Include configurația bazei de date

// Procesăm formularul
$message = '';
$message_type = '';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['add'])) {
        $name = $_POST['name'];
        $fiber_density = isset($_POST['fiber_density']) && $_POST['fiber_density'] !== '' ? $_POST['fiber_density'] : null;
        $flock_density = isset($_POST['flock_density']) && $_POST['flock_density'] !== '' ? $_POST['flock_density'] : null;
        $wood_density = isset($_POST['wood_density']) && $_POST['wood_density'] !== '' ? $_POST['wood_density'] : null;

        // Validare simplă
        if (!empty($name)) {
            // Pregătește și execută interogarea de inserare
            $stmt = $conn->prepare("INSERT INTO work_types (name, fiber_density, flock_density, wood_density) VALUES (?, ?, ?, ?)");
            $stmt->bind_param("sddd", $name, $fiber_density, $flock_density, $wood_density);

            if ($stmt->execute()) {
                header("Location: manage_work_types.php?message=success");
                exit();
            } else {
                $message = "Eroare: " . $stmt->error;
                $message_type = "error";
            }

            $stmt->close();
        } else {
            $message = "Te rog să completezi toate câmpurile obligatorii.";
            $message_type = "error";
        }
    }

    if (isset($_POST['edit'])) {
        $id = $_POST['id'];
        $name = $_POST['name'];
        $fiber_density = isset($_POST['fiber_density']) && $_POST['fiber_density'] !== '' ? $_POST['fiber_density'] : null;
        $flock_density = isset($_POST['flock_density']) && $_POST['flock_density'] !== '' ? $_POST['flock_density'] : null;
        $wood_density = isset($_POST['wood_density']) && $_POST['wood_density'] !== '' ? $_POST['wood_density'] : null;

        // Validare simplă
        if (!empty($name)) {
            // Pregătește și execută interogarea de actualizare
            $stmt = $conn->prepare("UPDATE work_types SET name = ?, fiber_density = ?, flock_density = ?, wood_density = ? WHERE id = ?");
            $stmt->bind_param("sdddi", $name, $fiber_density, $flock_density, $wood_density, $id);

            if ($stmt->execute()) {
                $message = "Tipul de muncă a fost actualizat cu succes.";
                $message_type = "success";
            } else {
                $message = "Eroare: " . $stmt->error;
                $message_type = "error";
            }

            $stmt->close();
        } else {
            $message = "Te rog să completezi toate câmpurile obligatorii.";
            $message_type = "error";
        }
    }
}

// Șterge tipul de muncă
if (isset($_GET['delete'])) {
    $id = intval($_GET['delete']);

    if ($stmt = $conn->prepare("DELETE FROM work_types WHERE id = ?")) {
        $stmt->bind_param("i", $id);

        if ($stmt->execute()) {
            $message = "Tipul de muncă a fost șters cu succes.";
            $message_type = "success";
        } else {
            $message = "Eroare: " . $stmt->error;
            $message_type = "error";
        }

        $stmt->close();
    }
}

// Obține tipurile de muncă existente
$work_types = [];
if ($result = $conn->query("SELECT id, name, fiber_density, flock_density, wood_density FROM work_types")) {
    while ($row = $result->fetch_assoc()) {
        $work_types[] = $row;
    }
    $result->free();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Gestionare Tipuri de Muncă</title>
    <style>
      /* Stilizare generală pentru corpul paginii */
body {
    font-family: 'Arial', sans-serif;
    margin: 0;
    padding: 0;
    background-color: #f0f4f8;
    display: flex;
    justify-content: center;
    align-items: flex-start;
    height: 100vh;
    overflow: auto;
}

/* Container pentru conținutul principal */
.container {
    width: 100%;
    max-width: 1000px;
    background-color: #ffffff;
    padding: 30px;
    border-radius: 10px;
    box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1);
    overflow: hidden;
}

/* Stilizare pentru titluri */
h1 {
    margin-top: 0;
    color: #333;
    font-size: 24px;
    border-bottom: 2px solid #4CAF50;
    padding-bottom: 10px;
}

/* Stilizare pentru formulare */
form {
    display: flex;
    flex-wrap: wrap;
    align-items: center;
    margin-bottom: 30px;
}

/* Stilizare pentru etichete */
label {
    margin-right: 10px;
    font-weight: bold;
    color: #555;
}

/* Stilizare pentru input-uri */
input[type="text"], input[type="number"], select {
    margin-right: 10px;
    padding: 10px;
    box-sizing: border-box;
    border: 1px solid #ddd;
    border-radius: 5px;
    width: auto;
}

/* Stilizare pentru butonul de submit */
input[type="submit"] {
    background-color: #4CAF50;
    color: white;
    border: none;
    cursor: pointer;
    padding: 10px 15px;
    border-radius: 5px;
    margin-left: 10px;
}

input[type="submit"]:hover {
    background-color: #45a049;
}

/* Mesaje */
.message {
    padding: 15px;
    margin-bottom: 20px;
    border-radius: 5px;
    color: #fff;
    text-align: center;
}

.message.success {
    background-color: #4CAF50;
}

.message.error {
    background-color: #f44336;
}

/* Container pentru tabel */
.scroll-container {
    max-height: 600px;
    overflow-y: auto;
    margin-bottom: 20px;
}

/* Stilizare pentru tabel */
table {
    width: 100%;
    border-collapse: collapse;
    table-layout: fixed;
}

/* Stilizare pentru celule de tabel */
table, th, td {
    border: 1px solid #ddd;
}

th, td {
    padding: 12px;
    text-align: left;
    color: #333;
    word-wrap: break-word;
}

/* Stilizare pentru header-ul tabelului */
th {
    background-color: #4CAF50;
    color: white;
}

/* Stilizare pentru butoanele de acțiune */
.actions button {
    background-color: #f44336;
    border: none;
    color: white;
    padding: 8px 12px;
    cursor: pointer;
    border-radius: 5px;
    margin-right: 5px;
    width: 80px; /* Ajustează dimensiunea butonului */
}

.actions .edit-btn {
    background-color: #4CAF50;
}

.actions .save-btn, .actions .cancel-btn {
    background-color: #2196F3;
}

.actions .delete-btn {
    background-color: #f44336;
}

.actions button.hidden {
    display: none;
}

.actions button:hover {
    opacity: 0.9;
}

/* Mesaj pentru lipsa de date */
.no-data {
    text-align: center;
    color: #999;
    margin-top: 20px;
}

/* Link pentru întoarcere */
.back-link {
    display: block;
    text-align: center;
    margin-top: 20px;
}

.back-link a {
    text-decoration: none;
    color: #4CAF50;
    font-weight: bold;
}

.back-link a:hover {
    text-decoration: underline;
}

/* Cursor pentru celule editabile */
.editable {
    cursor: pointer;
}

/* Ascundere elemente */
.hidden {
    display: none;
}

/* Dimensiuni personalizate pentru câmpurile de intrare */
#name {
    width: 150px; /* Ajustează lățimea pentru câmpul de denumire */
}

#fiber_density {
    width: 80px; /* Ajustează lățimea pentru câmpul de densitate fibre */
}

#flock_density {
    width: 80px; /* Ajustează lățimea pentru câmpul de densitate flock */
}

#wood_density {
    width: 80px; /* Ajustează lățimea pentru câmpul de densitate lemn */
}

    </style>
</head>
<body>
    <div class="container">
        <?php if (!empty($message)): ?>
            <div class="message <?php echo $message_type; ?>">
                <?php echo htmlspecialchars($message); ?>
            </div>
        <?php endif; ?>
        <?php if (isset($_GET['message']) && $_GET['message'] == 'success'): ?>
            <div class="message success">Tipul de muncă a fost adăugat cu succes.</div>
        <?php endif; ?>
        <h1>Adaugă Tip de Muncă</h1>
        <form method="post" action="">
            <label for="name">Denumire:</label>
            <input type="text" id="name" name="name" class="input-name" required>
            <label for="fiber_density">Densitate Fibre:</label>
            <input type="number" id="fiber_density" name="fiber_density" class="input-fiber-density" step="0.01">
            <label for="flock_density">Densitate Flock:</label>
            <input type="number" id="flock_density" name="flock_density" class="input-flock-density" step="0.01">
            <label for="wood_density">Densitate Lemn:</label>
            <input type="number" id="wood_density" name="wood_density" class="input-wood-density" step="0.01">
            <input type="submit" name="add" value="Adaugă">
        </form>

        <h1>Tipuri de Muncă Existente</h1>
        <div class="scroll-container">
            <?php if (!empty($work_types)): ?>
                <table>
                    <thead>
                        <tr>
                            <th>Denumire</th>
                            <th>Densitate Fibre</th>
                            <th>Densitate Flock</th>
                            <th>Densitate Lemn</th>
                            <th>Acțiuni</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($work_types as $work_type): ?>
                            <tr data-id="<?php echo $work_type['id']; ?>">
                                <td>
                                    <span class="name"><?php echo htmlspecialchars($work_type['name']); ?></span>
                                    <input type="text" class="edit-name hidden" value="<?php echo htmlspecialchars($work_type['name']); ?>">
                                </td>
                                <td>
                                    <span class="fiber_density"><?php echo htmlspecialchars($work_type['fiber_density']); ?></span>
                                    <input type="number" class="edit-fiber_density hidden" value="<?php echo htmlspecialchars($work_type['fiber_density']); ?>" step="0.01">
                                </td>
                                <td>
                                    <span class="flock_density"><?php echo htmlspecialchars($work_type['flock_density']); ?></span>
                                    <input type="number" class="edit-flock_density hidden" value="<?php echo htmlspecialchars($work_type['flock_density']); ?>" step="0.01">
                                </td>
                                <td>
                                    <span class="wood_density"><?php echo htmlspecialchars($work_type['wood_density']); ?></span>
                                    <input type="number" class="edit-wood_density hidden" value="<?php echo htmlspecialchars($work_type['wood_density']); ?>" step="0.01">
                                </td>
                                <td class="actions">
                                    <button class="edit-btn">Editează</button>
                                    <button class="save-btn hidden">Salvează</button>
                                    <button class="cancel-btn hidden">Anulează</button>
                                    <button class="delete-btn">Șterge</button>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            <?php else: ?>
                <p class="no-data">Nu există tipuri de muncă în baza de date.</p>
            <?php endif; ?>
        </div>

        <div class="back-link">
            <a href="index.php">Înapoi</a>
        </div>
    </div>

    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const tableBody = document.querySelector('tbody');

            tableBody.addEventListener('click', function(event) {
                const target = event.target;
                const row = target.closest('tr');

                if (!row) return;

                if (target.classList.contains('edit-btn')) {
                    row.querySelector('.name').classList.add('hidden');
                    row.querySelector('.edit-name').classList.remove('hidden');
                    row.querySelector('.fiber_density').classList.add('hidden');
                    row.querySelector('.edit-fiber_density').classList.remove('hidden');
                    row.querySelector('.flock_density').classList.add('hidden');
                    row.querySelector('.edit-flock_density').classList.remove('hidden');
                    row.querySelector('.wood_density').classList.add('hidden');
                    row.querySelector('.edit-wood_density').classList.remove('hidden');
                    row.querySelector('.edit-btn').classList.add('hidden');
                    row.querySelector('.save-btn').classList.remove('hidden');
                    row.querySelector('.cancel-btn').classList.remove('hidden');
                    row.querySelector('.delete-btn').classList.add('hidden');
                }

                if (target.classList.contains('save-btn')) {
                    const id = row.dataset.id;
                    const name = row.querySelector('.edit-name').value;
                    const fiber_density = row.querySelector('.edit-fiber_density').value;
                    const flock_density = row.querySelector('.edit-flock_density').value;
                    const wood_density = row.querySelector('.edit-wood_density').value;

                    fetch('update_work_type.php', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/json',
                        },
                        body: JSON.stringify({ id, name, fiber_density, flock_density, wood_density }),
                    })
                    .then(response => response.json())
                    .then(data => {
                        if (data.success) {
                            row.querySelector('.name').textContent = name;
                            row.querySelector('.fiber_density').textContent = parseFloat(fiber_density).toFixed(0);
                            row.querySelector('.flock_density').textContent = parseFloat(flock_density).toFixed(0);
                            row.querySelector('.wood_density').textContent = parseFloat(wood_density).toFixed(0);
                            row.querySelector('.name').classList.remove('hidden');
                            row.querySelector('.edit-name').classList.add('hidden');
                            row.querySelector('.fiber_density').classList.remove('hidden');
                            row.querySelector('.edit-fiber_density').classList.add('hidden');
                            row.querySelector('.flock_density').classList.remove('hidden');
                            row.querySelector('.edit-flock_density').classList.add('hidden');
                            row.querySelector('.wood_density').classList.remove('hidden');
                            row.querySelector('.edit-wood_density').classList.add('hidden');
                            row.querySelector('.edit-btn').classList.remove('hidden');
                            row.querySelector('.save-btn').classList.add('hidden');
                            row.querySelector('.cancel-btn').classList.add('hidden');
                            row.querySelector('.delete-btn').classList.remove('hidden');
                        } else {
                            alert('Eroare: ' + data.error);
                        }
                    })
                    .catch(error => {
                        alert('Eroare: ' + error.message);
                    });
                }

                if (target.classList.contains('cancel-btn')) {
                    row.querySelector('.name').classList.remove('hidden');
                    row.querySelector('.edit-name').classList.add('hidden');
                    row.querySelector('.fiber_density').classList.remove('hidden');
                    row.querySelector('.edit-fiber_density').classList.add('hidden');
                    row.querySelector('.flock_density').classList.remove('hidden');
                    row.querySelector('.edit-flock_density').classList.add('hidden');
                    row.querySelector('.wood_density').classList.remove('hidden');
                    row.querySelector('.edit-wood_density').classList.add('hidden');
                    row.querySelector('.edit-btn').classList.remove('hidden');
                    row.querySelector('.save-btn').classList.add('hidden');
                    row.querySelector('.cancel-btn').classList.add('hidden');
                    row.querySelector('.delete-btn').classList.remove('hidden');
                }

                if (target.classList.contains('delete-btn')) {
                    if (confirm('Sigur dorești să ștergi acest tip de muncă?')) {
                        const id = row.dataset.id;

                        fetch('delete_work_type.php', {
                            method: 'POST',
                            headers: {
                                'Content-Type': 'application/json',
                            },
                            body: JSON.stringify({ id }),
                        })
                        .then(response => response.json())
                        .then(data => {
                            if (data.success) {
                                row.remove();
                                showMessage('Tipul de muncă a fost șters cu succes.', 'success');
                            } else {
                                showMessage('Eroare: ' + data.error, 'error');
                            }
                        })
                        .catch(error => {
                            showMessage('Eroare: ' + error.message, 'error');
                        });
                    }
                }
            });

            function showMessage(message, type) {
                const messageBox = document.createElement('div');
                messageBox.textContent = message;
                messageBox.className = 'message ' + type;

                const container = document.querySelector('.container');
                container.insertBefore(messageBox, container.firstChild);

                setTimeout(() => messageBox.remove(), 5000); // Mesajul dispare după 5 secunde
            }

            const initialMessage = document.querySelector('.message');
            if (initialMessage) {
                setTimeout(() => initialMessage.remove(), 5000); // Mesajul dispare după 5 secunde
            }
        });
    </script>
</body>
</html>
