<?php
include 'config.php'; // Include configurația bazei de date

// Începeți sesiunea dacă nu este deja începută
session_start();

// Verificăm dacă cererea este de tip POST
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Obținem datele trimise prin POST
    $data = json_decode(file_get_contents('php://input'), true);

    // Debugging: Afișăm datele primite pentru a verifica dacă sunt complete
    error_log(print_r($data, true));

    // Verificăm dacă datele sunt valide
    if (isset($data['id'], $data['category_id'], $data['name'], $data['pret_unitar_iesire'], $data['unitate_masura'])) {
        $id = intval($data['id']);
        $category_id = intval($data['category_id']);
        $name = trim($data['name']);
        $pret_unitar_intrare = isset($data['pret_unitar_intrare']) && $data['pret_unitar_intrare'] !== '' ? floatval($data['pret_unitar_intrare']) : null;
        $pret_unitar_iesire = floatval($data['pret_unitar_iesire']);
        $unitate_masura = trim($data['unitate_masura']);
        $dimensiune = isset($data['dimensiune']) && $data['dimensiune'] !== '' ? intval($data['dimensiune']) : null;

        // Validare simplă
        if (!empty($name) && !empty($unitate_masura) && $pret_unitar_iesire >= 0) {
            // Pregătește și execută interogarea de actualizare
            if ($stmt = $conn->prepare("UPDATE materials SET category_id = ?, name = ?, pret_unitar_intrare = ?, pret_unitar_iesire = ?, unitate_masura = ?, dimensiune = ? WHERE id = ?")) {
                $stmt->bind_param("issdsii", $category_id, $name, $pret_unitar_intrare, $pret_unitar_iesire, $unitate_masura, $dimensiune, $id);

                if ($stmt->execute()) {
                    echo json_encode(['success' => true]);
                } else {
                    echo json_encode(['success' => false, 'error' => 'Eroare: ' . $stmt->error]);
                }

                $stmt->close();
            } else {
                echo json_encode(['success' => false, 'error' => 'Eroare: ' . $conn->error]);
            }
        } else {
            echo json_encode(['success' => false, 'error' => 'Date incomplete sau invalide']);
        }
    } else {
        echo json_encode(['success' => false, 'error' => 'Date incomplete']);
    }
} else {
    echo json_encode(['success' => false, 'error' => 'Metodă de cerere neacceptată']);
}

$conn->close();
?>
