<?php

include 'auth_check.php';
include 'config.php';

$message = "";

if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_FILES['xmlFiles'])) {
    foreach ($_FILES['xmlFiles']['tmp_name'] as $key => $tmp_name) {
        if (file_exists($tmp_name)) {
            $xml = simplexml_load_file($tmp_name);
            foreach ($xml->factura as $factura) {
                $furnizor_id = (int)$factura->furnizor_id;
                $nr_factura = (string)$factura->nr_factura;
                $data_factura = (string)$factura->data_factura;
                $data_scadenta = (string)$factura->data_scadenta;
                $total_factura = (float)$factura->total_factura;

                $sql = "INSERT INTO facturi (furnizor_id, nr_factura, data_factura, data_scadenta, total_factura) 
                        VALUES (?, ?, ?, ?, ?)";
                $stmt = $conn->prepare($sql);
                $stmt->bind_param("isssd", $furnizor_id, $nr_factura, $data_factura, $data_scadenta, $total_factura);
                
                if ($stmt->execute()) {
                    $message .= "Factura " . htmlspecialchars($nr_factura) . " a fost adăugată cu succes.<br>";
                } else {
                    $message .= "Eroare la adăugarea facturii " . htmlspecialchars($nr_factura) . ": " . $stmt->error . "<br>";
                }
                
                $stmt->close();
            }
        } else {
            $message .= "Eroare la procesarea fișierului " . htmlspecialchars($_FILES["xmlFiles"]["name"][$key]) . ".<br>";
        }
    }
} elseif ($_SERVER["REQUEST_METHOD"] == "POST") {
    $furnizor_id = $_POST['furnizor_id'];
    $nr_factura = $_POST['nr_factura'];
    $data_factura = $_POST['data_factura'];
    $data_scadenta = $_POST['data_scadenta'];
    $total_factura = $_POST['total_factura'];

    $sql = "INSERT INTO facturi (furnizor_id, nr_factura, data_factura, data_scadenta, total_factura) VALUES (?, ?, ?, ?, ?)";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("isssd", $furnizor_id, $nr_factura, $data_factura, $data_scadenta, $total_factura);
    $stmt->execute();

    if ($stmt->affected_rows > 0) {
        $message = "Factura a fost adăugată cu succes!";
    } else {
        $message = "Eroare la adăugarea facturii: " . $stmt->error;
    }
    $stmt->close();
    $conn->close();
    
    header("Location: add_factura.php?message=" . urlencode($message));
    exit();
}

if (isset($_GET['message'])) {
    $message = $_GET['message'];
}

if (isset($_GET['facturiAdaugate']) || isset($_GET['facturiExistente'])) {
    $facturiAdaugate = intval($_GET['facturiAdaugate']);
    $facturiExistente = intval($_GET['facturiExistente']);
    
    if ($facturiAdaugate > 0) {
        $message .= "Facturi adăugate: $facturiAdaugate";
    }
    
    if ($facturiExistente > 0) {
        $message .= "Facturi deja existente: $facturiExistente";
    }
}
?>

<!DOCTYPE html>
<html lang="ro">
<head>
    <meta charset="UTF-8">
    <title>Gestionare Facturi</title>
    <link href="https://cdn.jsdelivr.net/npm/flatpickr/dist/flatpickr.min.css" rel="stylesheet">
    <style>
        :root {
            --primary-color: #3498db;
            --secondary-color: #2ecc71;
            --danger-color: #e74c3c;
            --warning-color: #f39c12;
            --bg-color: #f4f6f9;
            --text-color: #34495e;
            --border-radius: 12px;
        }

        body {
            display: flex;
            justify-content: center;
            align-items: flex-start;
            height: 100vh;
            padding: 20px;
            margin: 0;
            background-color: var(--bg-color);
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
        }

        .container {
            background-color: #ffffff;
            padding: 20px;
            border-radius: var(--border-radius);
            box-shadow: 0 10px 25px rgba(0, 0, 0, 0.1);
            max-width: 600px;
            width: 100%;
            animation: fadeIn 0.5s ease-in-out;
            margin-top: 30px;
        }

        @keyframes fadeIn {
            from { opacity: 0; transform: translateY(20px); }
            to { opacity: 1; transform: translateY(0); }
        }

        .message {
            text-align: center;
            margin-bottom: 20px;
            font-size: 16px;
        }

        .message.success {
            color: green;
        }

        .message.error {
            color: red;
        }

        .form-group label {
            font-weight: bold;
            color: var(--text-color);
            margin-bottom: 5px;
            display: block;
        }

        .form-group input[type="text"], 
        .form-group input[type="number"], 
        .form-group input[type="file"],
        .form-group input[type="date"],
        .form-group select {
            width: 100%;
            padding: 12px;
            border: 1px solid #ddd;
            border-radius: var(--border-radius);
            font-size: 14px;
            margin-bottom: 10px;
            box-sizing: border-box;
        }

        .form-group select {
            appearance: none;
            background-color: #fff;
            background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 4 5"><path fill="%23000" d="M2 0L0 2h4zM2 5L0 3h4z"/></svg>');
            background-repeat: no-repeat;
            background-position: right 10px center;
            background-size: 10px;
        }

        .btn {
            border-radius: var(--border-radius);
            padding: 10px;
            font-size: 14px;
            transition: transform 0.2s ease;
            cursor: pointer;
            text-align: center;
            color: #fff;
            border: none;
            width: 100%;
            text-decoration: none;
            margin-bottom: 10px;
        }

        .btn:hover {
            transform: scale(1.05);
        }

        .btn-success {
            background-color: var(--secondary-color);
        }

        .btn-success:hover {
            background-color: #27ae60;
        }

        .btn-warning {
            background-color: var(--warning-color);
        }

        .btn-warning:hover {
            background-color: #e0a800;
        }

        .btn-secondary {
            background-color: var(--primary-color);
        }

        .btn-secondary:hover {
            background-color: #2980b9;
        }

        .btn-import {
            background-color: var(--primary-color);
            margin-top: 20px;
            border-radius: var(--border-radius);
            transition: transform 0.2s ease;
        }

        .btn-import:hover {
            transform: scale(1.05);
            background-color: #2980b9;
        }

        .btn-group {
            display: flex;
            justify-content: space-between;
            gap: 10px;
            margin-top: 20px;
        }

        .form-row {
            display: flex;
            gap: 10px;
            flex-wrap: wrap;
        }

        .form-group {
            flex: 1;
            min-width: 100px;
        }
    </style>
    <script src="https://cdn.jsdelivr.net/npm/flatpickr"></script>
    <script>
        function toggleImportForm() {
            var form = document.getElementById('importForm');
            form.style.display = form.style.display === 'none' || form.style.display === '' ? 'block' : 'none';
        }

        document.addEventListener('DOMContentLoaded', function() {
            flatpickr('#data_factura', {
                dateFormat: "Y-m-d",
                locale: "ro"
            });
            flatpickr('#data_scadenta', {
                dateFormat: "Y-m-d",
                locale: "ro"
            });
        });
    </script>
</head>
<body>
    <div class="container">
        <?php if ($message): ?>
            <p class="message <?php echo strpos($message, 'succes') !== false ? 'success' : 'error'; ?>"><?php echo htmlspecialchars($message); ?></p>
        <?php endif; ?>
        <form method="post" action="add_factura.php">
            <div class="form-row">
                <div class="form-group">
                    <label for="furnizor_id">Furnizor:</label>
                    <select name="furnizor_id" id="furnizor_id" required>
                        <?php
                        $sql = "SELECT id, nume FROM furnizori";
                        $result = $conn->query($sql);
                        if ($result->num_rows > 0) {
                            while ($row = $result->fetch_assoc()) {
                                echo "<option value='" . $row['id'] . "'>" . htmlspecialchars($row['nume']) . "</option>";
                            }
                        } else {
                            echo "<option value=''>Niciun furnizor disponibil</option>";
                        }
                        ?>
                    </select>
                </div>
                <div class="form-group">
                    <label for="nr_factura">Nr. Factură:</label>
                    <input type="text" id="nr_factura" name="nr_factura" required>
                </div>
                <div class="form-group">
                    <label for="total_factura">Total Factură:</label>
                    <input type="number" id="total_factura" name="total_factura" step="0.01" required>
                </div>
            </div>
            <div class="form-row">
                <div class="form-group">
                    <label for="data_factura">Data Factură:</label>
                    <input type="date" id="data_factura" name="data_factura" required>
                </div>
                <div class="form-group">
                    <label for="data_scadenta">Data Scadență:</label>
                    <input type="date" id="data_scadenta" name="data_scadenta" required>
                </div>
            </div>
            <div class="btn-group">
                <input type="submit" value="Adaugă" class="btn btn-success">
                <a href="view_facturi.php" class="btn btn-warning">Vezi facturi</a>
                <a href="index.php" class="btn btn-secondary">Înapoi</a>
            </div>
        </form>
        <button class="btn btn-import" onclick="toggleImportForm()">Importă Facturi XML</button>
        <div id="importForm" class="animate__animated animate__fadeIn" style="display: none;">
            <form method="post" enctype="multipart/form-data" action="import_facturi.php">
                <div class="form-group">
                    <label for="xmlFiles">Selectează fișiere XML:</label>
                    <input type="file" name="xmlFiles[]" id="xmlFiles" multiple accept=".xml" required>
                </div>
                <div class="btn-group">
                    <input type="submit" value="Importă" class="btn btn-success">
                </div>
            </form>
        </div>
    </div>
</body>
</html>
