<?php
include 'auth_check.php';
include 'config.php';

$message = "";

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $nume = $_POST['nume'];
    $zile_scadenta = $_POST['zile_scadenta'];

    // Verificăm dacă furnizorul există deja în baza de date
    $sql = "SELECT id FROM furnizori WHERE nume = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $nume);
    $stmt->execute();
    $stmt->store_result();

    if ($stmt->num_rows > 0) {
        // Furnizorul există deja
        $message = "Furnizorul există deja în baza de date.";
    } else {
        // Inserarea furnizorului în baza de date
        $sql = "INSERT INTO furnizori (nume, zile_scadenta) VALUES (?, ?)";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("si", $nume, $zile_scadenta);
        $stmt->execute();

        if ($stmt->affected_rows > 0) {
            $message = "Furnizor adăugat cu succes!";
        } else {
            $message = "Eroare la adăugarea furnizorului: " . $stmt->error;
        }
    }
    $stmt->close();
    $conn->close();
}
?>

<!DOCTYPE html>
<html lang="ro">
<head>
    <meta charset="UTF-8">
    <title>Adaugă Furnizor</title>
    <style>
        :root {
            --primary-color: #3498db; /* Albastru */
            --secondary-color: #2ecc71; /* Verde */
            --danger-color: #e74c3c; /* Roșu */
            --warning-color: #f39c12; /* Galben */
            --bg-color: #f4f6f9; /* Gri deschis */
            --text-color: #34495e; /* Gri închis */
            --border-radius: 12px;
        }

        body {
            display: flex;
            justify-content: center;
            align-items: flex-start; /* Mutăm formularul mai sus */
            height: 100vh;
            padding: 20px;
            margin: 0;
            background-color: var(--bg-color);
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
        }

        .container {
            background-color: #ffffff;
            padding: 20px;
            border-radius: var(--border-radius);
            box-shadow: 0 10px 25px rgba(0, 0, 0, 0.1);
            max-width: 400px;
            width: 100%;
            animation: fadeIn 0.5s ease-in-out; /* Animație pentru afișare */
            margin-top: 30px; /* Poziționează mai sus formularul */
        }

        @keyframes fadeIn {
            from { opacity: 0; transform: translateY(20px); }
            to { opacity: 1; transform: translateY(0); }
        }

        .message {
            text-align: center;
            margin-bottom: 20px;
            font-size: 16px;
        }

        .message.success {
            color: green;
        }

        .message.error {
            color: red;
        }

        .form-group label {
            font-weight: bold;
            color: var(--text-color);
            margin-bottom: 5px;
            display: block;
        }

        .form-group input[type="text"], 
        .form-group input[type="number"], 
        .form-group input[type="file"] {
            width: 100%;
            padding: 12px;
            border: 1px solid #ddd;
            border-radius: var(--border-radius);
            font-size: 14px;
            margin-bottom: 10px;
            box-sizing: border-box;
        }

        .btn {
            border-radius: var(--border-radius);
            padding: 10px;
            font-size: 14px;
            transition: transform 0.2s ease;
            cursor: pointer;
            text-align: center;
            color: #fff;
            border: none;
            width: 100%;
            text-decoration: none;
            margin-bottom: 10px;
        }

        .btn:hover {
            transform: scale(1.05);
        }

        .btn-success {
            background-color: var(--secondary-color);
        }

        .btn-success:hover {
            background-color: #27ae60;
        }

        .btn-warning {
            background-color: var(--warning-color);
        }

        .btn-warning:hover {
            background-color: #e0a800;
        }

        .btn-secondary {
            background-color: var(--primary-color);
        }

        .btn-secondary:hover {
            background-color: #2980b9;
        }

        .btn-group {
            display: flex;
            justify-content: space-between;
            gap: 10px;
            margin-top: 20px;
        }

        .form-row {
            display: flex;
            gap: 10px;
            flex-wrap: wrap;
        }

        .form-group {
            flex: 1;
            min-width: 100px;
        }
    </style>
</head>
<body>
    <div class="container">
        <?php if ($message != ""): ?>
            <p class="message <?php echo $message == 'Furnizor adăugat cu succes!' ? 'success' : 'error'; ?>"><?php echo $message; ?></p>
        <?php endif; ?>
        <form method="post" action="add_furnizor.php" enctype="multipart/form-data">
            <div class="form-row">
                <div class="form-group">
                    <label for="nume" class="form-label">Furnizor:</label>
                    <input type="text" id="nume" name="nume" required>
                </div>
                <div class="form-group">
                    <label for="zile_scadenta" class="form-label">Scadență:</label>
                    <input type="number" id="zile_scadenta" name="zile_scadenta" required>
                </div>
            </div>
            <div class="btn-group">
                <input type="submit" value="Adaugă" class="btn btn-success">
                <a href="view_furnizori.php" class="btn btn-warning">Editează</a>
                <a href="index.php" class="btn btn-secondary">Înapoi</a>
            </div>
        </form>
    </div>
</body>
</html>
