<?php
include 'config.php'; // Include fișierul cu configurația bazei de date

// Setează calea fișierului HTML
$html_file_path = 'due_invoices.html';

// Obține data curentă
$current_date = date('Y-m-d');

// Obține facturile scadente
$sql = "
    SELECT f.nr_factura, f.data_factura, f.data_scadenta, f.total_factura, fn.nume AS furnizor, fn.zile_scadenta
    FROM facturi f
    INNER JOIN furnizori fn ON f.furnizor_id = fn.id
    WHERE f.data_scadenta <= ?
    ORDER BY f.data_scadenta
";

$stmt = $conn->prepare($sql);
$stmt->bind_param("s", $current_date);
$stmt->execute();
$result = $stmt->get_result();

// Inițializare variabile pentru totaluri
$total_amount = 0;
$provider_totals = [];
$days_overdue = [];

// HTML pentru email
$email_body = "<html><head><meta charset='UTF-8'><style>
    body { font-family: Arial, sans-serif; margin: 0; padding: 20px; }
    h1 { text-align: center; color: #333; }
    table { width: 70%; border-collapse: collapse; margin: 0 auto; }
    th, td { border: 1px solid #ddd; padding: 6px; text-align: left; }
    th { background-color: #f4f4f4; }
    .total { font-weight: bold; font-size: 25px; }
    .overdue { color: red; }
    .provider-total-table { width: 20%; border: none; margin: 10px 0; }
    .provider-total-table td { font-size: 16px; text-align: left; border: none; padding: 4px; }
    .provider-total-table .provider { font-weight: bold; padding-right: 10px; }
    .provider-total-table .total { padding-left: 10px; }
    @media (max-width: 600px) {
        table { width: 100%; }
    }
</style></head><body>";
$email_body .= "<h1>Facturi Scadente</h1>";
$email_body .= "<table>";
$email_body .= "<tr><th>Nr. Factură</th><th>Data Factură</th><th>Data Scadență</th><th>Total Factură</th><th>Furnizor</th><th>Zile Întârziere</th></tr>";

while ($row = $result->fetch_assoc()) {
    $days_overdue = max(0, (strtotime($current_date) - strtotime($row['data_scadenta'])) / (60 * 60 * 24)); // Calculare zile întârziere
    $days_overdue_display = $days_overdue > 0 ? $days_overdue : 'N/A';
    
    $total_amount += $row['total_factura'];

    // Adaugă totalul pe furnizor
    if (!isset($provider_totals[$row['furnizor']])) {
        $provider_totals[$row['furnizor']] = 0;
    }
    $provider_totals[$row['furnizor']] += $row['total_factura'];

    $email_body .= "<tr>";
    $email_body .= "<td>" . htmlspecialchars($row['nr_factura']) . "</td>";
    $email_body .= "<td>" . htmlspecialchars($row['data_factura']) . "</td>";
    $email_body .= "<td>" . htmlspecialchars($row['data_scadenta']) . "</td>";
    $email_body .= "<td>" . number_format($row['total_factura'], 2) . "</td>";
    $email_body .= "<td>" . htmlspecialchars($row['furnizor']) . "</td>";
    $email_body .= "<td class='" . ($days_overdue > 0 ? 'overdue' : '') . "'>" . $days_overdue_display . "</td>";
    $email_body .= "</tr>";
}

// Adaugă totaluri per furnizor
$email_body .= "<tr><td colspan='6'><h3>Totaluri pe Furnizor:</h3><table class='provider-total-table'>";
foreach ($provider_totals as $provider => $total) {
    $email_body .= "<tr><td class='provider'>" . htmlspecialchars($provider) . "</td><td class='total'>" . number_format($total, 2) . "</td></tr>";
}
$email_body .= "</table></td></tr>";

// Adaugă totalul general
$email_body .= "<tr><td colspan='6' class='total'>Total General: " . number_format($total_amount, 2) . "</td></tr>";

$email_body .= "</table></body></html>";

// Salvează fișierul HTML
file_put_contents($html_file_path, $email_body);

// Închide conexiunea la baza de date
$stmt->close();
$conn->close();
?>
